@@ -51,7 +51,7 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
                 },
             ],
         },
-        "0.1.1-rc.1": {
+        "0.1.1-alpha.1": {
             "changelog_sections": {
                 "angular": [{"section": "Bug Fixes", "i_commits": [0]}],
                 "emoji": [{"section": ":bug:", "i_commits": [0]}],
@@ -67,9 +67,18 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
         },
         "1.0.0-rc.1": {
             "changelog_sections": {
-                "angular": [{"section": "Breaking", "i_commits": [0]}],
-                "emoji": [{"section": ":boom:", "i_commits": [0]}],
-                "scipy": [{"section": "Breaking", "i_commits": [0]}],
+                "angular": [
+                    {"section": "Breaking", "i_commits": [0]},
+                    {"section": "Unknown", "i_commits": [1]},
+                ],
+                "emoji": [
+                    {"section": ":boom:", "i_commits": [0]},
+                    {"section": "Other", "i_commits": [1]},
+                ],
+                "scipy": [
+                    {"section": "Breaking", "i_commits": [0]},
+                    {"section": "Unknown", "i_commits": [1]},
+                ],
             },
             "commits": [
                 {
@@ -85,14 +94,37 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
                         "msg": "API: add revolutionary feature",
                         "sha": NULL_HEX_SHA,
                     },
-                }
+                },
+                {
+                    "angular": {
+                        "msg": "Merge branch 'feat/feature-1' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": "Merge branch 'feat/feature-1' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "Merge branch 'feat/feature-1' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                },
             ],
         },
         "1.0.0": {
             "changelog_sections": {
-                "angular": [{"section": "Features", "i_commits": [0]}],
-                "emoji": [{"section": ":sparkles:", "i_commits": [0]}],
-                "scipy": [{"section": "Feature", "i_commits": [0]}],
+                "angular": [
+                    {"section": "Features", "i_commits": [0]},
+                    {"section": "Unknown", "i_commits": [2, 1]},
+                ],
+                "emoji": [
+                    {"section": ":sparkles:", "i_commits": [0]},
+                    {"section": "Other", "i_commits": [2, 1]},
+                ],
+                "scipy": [
+                    {"section": "Feature", "i_commits": [0]},
+                    {"section": "Unknown", "i_commits": [2, 1]},
+                ],
             },
             "commits": [
                 {
@@ -102,10 +134,38 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
                         "sha": NULL_HEX_SHA,
                     },
                     "scipy": {"msg": "ENH: add some more text", "sha": NULL_HEX_SHA},
-                }
+                },
+                {
+                    "angular": {
+                        "msg": "Merge branch 'feat/feature-2' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": "Merge branch 'feat/feature-2' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "Merge branch 'feat/feature-2' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                },
+                {
+                    "angular": {
+                        "msg": "Merge branch 'dev' into 'main'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": "Merge branch 'dev' into 'main'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "Merge branch 'dev' into 'main'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                },
             ],
         },
-        "1.1.0-rc.1": {
+        "1.1.0-alpha.1": {
             "changelog_sections": {
                 "angular": [{"section": "Features", "i_commits": [0]}],
                 "emoji": [{"section": ":sparkles:", "i_commits": [0]}],
@@ -125,16 +185,62 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
                         "msg": "ENH(dev): add some more text",
                         "sha": NULL_HEX_SHA,
                     },
-                }
+                },
             ],
         },
-        "1.1.0-rc.2": {
+        "1.1.0-alpha.2": {
             "changelog_sections": {
-                "angular": [{"section": "Bug Fixes", "i_commits": [0]}],
-                "emoji": [{"section": ":bug:", "i_commits": [0]}],
-                "scipy": [{"section": "Fix", "i_commits": [0]}],
+                "angular": [{"section": "Features", "i_commits": [0]}],
+                "emoji": [{"section": ":sparkles:", "i_commits": [0]}],
+                "scipy": [{"section": "Feature", "i_commits": [0]}],
             },
             "commits": [
+                {
+                    "angular": {
+                        "msg": "feat(dev): add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": ":sparkles: (dev) add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "ENH(dev): add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                },
+            ],
+        },
+        "1.1.0-rc.1": {
+            "changelog_sections": {
+                "angular": [
+                    {"section": "Bug Fixes", "i_commits": [1]},
+                    {"section": "Unknown", "i_commits": [2, 0]},
+                ],
+                "emoji": [
+                    {"section": ":bug:", "i_commits": [1]},
+                    {"section": "Other", "i_commits": [2, 0]},
+                ],
+                "scipy": [
+                    {"section": "Fix", "i_commits": [1]},
+                    {"section": "Unknown", "i_commits": [2, 0]},
+                ],
+            },
+            "commits": [
+                {
+                    "angular": {
+                        "msg": "Merge branch 'feat/feature-3' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": "Merge branch 'feat/feature-3' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "Merge branch 'feat/feature-3' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                },
                 {
                     "angular": {
                         "msg": "fix(dev): correct some text",
@@ -148,37 +254,37 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
                         "msg": "MAINT(dev): correct some text",
                         "sha": NULL_HEX_SHA,
                     },
-                }
-            ],
-        },
-        "1.1.0-alpha.1": {
-            "changelog_sections": {
-                "angular": [{"section": "Features", "i_commits": [0]}],
-                "emoji": [{"section": ":sparkles:", "i_commits": [0]}],
-                "scipy": [{"section": "Feature", "i_commits": [0]}],
-            },
-            "commits": [
+                },
                 {
                     "angular": {
-                        "msg": "feat(scope): add some more text",
+                        "msg": "Merge branch 'fix/patch-1' into 'dev'",
                         "sha": NULL_HEX_SHA,
                     },
                     "emoji": {
-                        "msg": ":sparkles: add scoped change",
+                        "msg": "Merge branch 'fix/patch-1' into 'dev'",
                         "sha": NULL_HEX_SHA,
                     },
                     "scipy": {
-                        "msg": "ENH(scope): add some more text",
+                        "msg": "Merge branch 'fix/patch-1' into 'dev'",
                         "sha": NULL_HEX_SHA,
                     },
-                }
+                },
             ],
         },
-        "1.1.0-alpha.2": {
+        "1.1.0-rc.2": {
             "changelog_sections": {
-                "angular": [{"section": "Features", "i_commits": [0]}],
-                "emoji": [{"section": ":sparkles:", "i_commits": [0]}],
-                "scipy": [{"section": "Feature", "i_commits": [0]}],
+                "angular": [
+                    {"section": "Features", "i_commits": [0]},
+                    {"section": "Unknown", "i_commits": [1]},
+                ],
+                "emoji": [
+                    {"section": ":sparkles:", "i_commits": [0]},
+                    {"section": "Other", "i_commits": [1]},
+                ],
+                "scipy": [
+                    {"section": "Feature", "i_commits": [0]},
+                    {"section": "Unknown", "i_commits": [1]},
+                ],
             },
             "commits": [
                 {
@@ -195,13 +301,38 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
                         "sha": NULL_HEX_SHA,
                     },
                 },
+                {
+                    "angular": {
+                        "msg": "Merge branch 'feat/feature-4' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": "Merge branch 'feat/feature-4' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "Merge branch 'feat/feature-4' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                },
             ],
         },
-        "1.1.0-alpha.3": {
+        # TODO: shouldn't be any commit, just a merge into main and release rc.2 as it was successful
+        # this is not implemented because currently not supported
+        "1.1.0": {
             "changelog_sections": {
-                "angular": [{"section": "Bug Fixes", "i_commits": [0]}],
-                "emoji": [{"section": ":bug:", "i_commits": [0]}],
-                "scipy": [{"section": "Fix", "i_commits": [0]}],
+                "angular": [
+                    {"section": "Bug Fixes", "i_commits": [0]},
+                    {"section": "Unknown", "i_commits": [2, 1]},
+                ],
+                "emoji": [
+                    {"section": ":bug:", "i_commits": [0]},
+                    {"section": "Other", "i_commits": [2, 1]},
+                ],
+                "scipy": [
+                    {"section": "Fix", "i_commits": [0]},
+                    {"section": "Unknown", "i_commits": [2, 1]},
+                ],
             },
             "commits": [
                 {
@@ -217,7 +348,35 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
                         "msg": "MAINT(scope): correct some text",
                         "sha": NULL_HEX_SHA,
                     },
-                }
+                },
+                {
+                    "angular": {
+                        "msg": "Merge branch 'fix/patch-2' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": "Merge branch 'fix/patch-2' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "Merge branch 'fix/patch-2' into 'dev'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                },
+                {
+                    "angular": {
+                        "msg": "Merge branch 'dev' into 'main'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": "Merge branch 'dev' into 'main'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "Merge branch 'dev' into 'main'",
+                        "sha": NULL_HEX_SHA,
+                    },
+                },
             ],
         },
     }
@@ -281,15 +440,20 @@ def build_git_flow_repo_w_3_release_channels(
             hvcs_domain=hvcs_domain,
             tag_format_str=tag_format_str,
             extra_configs={
+                # Set the default release branch
+                "tool.semantic_release.branches.main": {
+                    "match": r"^(main|master)$",
+                    "prerelease": False,
+                },
                 # branch "dev" has prerelease suffix of "rc"
                 "tool.semantic_release.branches.dev": {
-                    "match": "dev",
+                    "match": r"^dev$",
                     "prerelease": True,
                     "prerelease_token": "rc",
                 },
                 # branch "feature" has prerelease suffix of "alpha"
                 "tool.semantic_release.branches.features": {
-                    "match": "feat.*",
+                    "match": r"feat/.+",
                     "prerelease": True,
                     "prerelease_token": "alpha",
                 },
@@ -315,6 +479,9 @@ def build_git_flow_repo_w_3_release_channels(
                 next_version_def["commits"],
             )
 
+            # Grab reference to the main branch
+            main_branch_head = git_repo.heads["main"]
+
             # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
@@ -340,7 +507,19 @@ def build_git_flow_repo_w_3_release_channels(
             next_version = next(versions)
             next_version_def = repo_def[next_version]
 
-            # Prepare for a prerelease
+            # Change to a dev branch
+            dev_branch_head = git_repo.create_head(
+                "dev", commit=main_branch_head.commit
+            )
+            dev_branch_head.checkout()
+
+            # Change to a feature branch
+            feat_branch_head = git_repo.create_head(
+                "feat/feature-1", commit=dev_branch_head.commit
+            )
+            feat_branch_head.checkout()
+
+            # Prepare for a prerelease (by adding a change, direct commit to dev branch)
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
                 git_repo,
                 next_version_def["commits"],
@@ -364,7 +543,7 @@ def build_git_flow_repo_w_3_release_channels(
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
-            # Make a patch level release candidate (v0.1.1-rc.1)
+            # Make a patch level alpha release (v0.1.1-alpha.1)
             create_release_tagged_commit(git_repo, next_version, tag_format)
 
             # Increment version pointer
@@ -372,10 +551,24 @@ def build_git_flow_repo_w_3_release_channels(
             next_version_def = repo_def[next_version]
 
             # Prepare for a major feature release
-            next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo,
-                next_version_def["commits"],
+            next_version_def["commits"] = [
+                *simulate_change_commits_n_rtn_changelog_entry(
+                    git_repo,
+                    next_version_def["commits"][:-1],
+                ),
+                *next_version_def["commits"][-1:],
+            ]
+
+            # checkout dev branch (in prep for merge)
+            dev_branch_head.checkout()
+
+            # Merge feature branch into dev branch
+            git_repo.git.merge(
+                feat_branch_head.name,
+                no_ff=True,
+                m=next_version_def["commits"][-1]["msg"],
             )
+            next_version_def["commits"][-1]["sha"] = git_repo.head.commit.hexsha
 
             # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
@@ -402,11 +595,42 @@ def build_git_flow_repo_w_3_release_channels(
             next_version = next(versions)
             next_version_def = repo_def[next_version]
 
-            # Add non-breaking feature commit
-            next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo,
-                next_version_def["commits"],
+            # Switch to a feature branch
+            feat_branch_head = git_repo.create_head(
+                "feat/feature-2", commit=dev_branch_head.commit
             )
+            feat_branch_head.checkout()
+
+            # Add non-breaking feature commit
+            next_version_def["commits"] = [
+                *simulate_change_commits_n_rtn_changelog_entry(
+                    git_repo,
+                    next_version_def["commits"][:-2],
+                ),
+                *next_version_def["commits"][-2:],
+            ]
+
+            # checkout dev branch (in prep for merge)
+            dev_branch_head.checkout()
+
+            # Merge feature branch into dev branch
+            git_repo.git.merge(
+                feat_branch_head.name,
+                no_ff=True,
+                m=next_version_def["commits"][-2]["msg"],
+            )
+            next_version_def["commits"][-2]["sha"] = git_repo.head.commit.hexsha
+
+            # checkout main branch (in prep for merge & release)
+            main_branch_head.checkout()
+
+            # Merge dev branch into main branch
+            git_repo.git.merge(
+                dev_branch_head.name,
+                no_ff=True,
+                m=next_version_def["commits"][-1]["msg"],
+            )
+            next_version_def["commits"][-1]["sha"] = git_repo.head.commit.hexsha
 
             # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
@@ -433,9 +657,15 @@ def build_git_flow_repo_w_3_release_channels(
             next_version = next(versions)
             next_version_def = repo_def[next_version]
 
-            # Change to a dev branch
-            git_repo.create_head("dev")
-            git_repo.heads.dev.checkout()
+            # Update & Change to the dev branch
+            dev_branch_head.checkout()
+            git_repo.git.merge(main_branch_head.name, ff=True)
+
+            # Switch to a feature branch
+            feat_branch_head = git_repo.create_head(
+                "feat/feature-3", commit=dev_branch_head.commit
+            )
+            feat_branch_head.checkout()
 
             # Prepare for a minor bump release candidate
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
@@ -461,7 +691,7 @@ def build_git_flow_repo_w_3_release_channels(
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
-            # Make a minor bump release candidate (v1.1.0-rc.1)
+            # Make a minor bump release candidate (v1.1.0-alpha.1)
             create_release_tagged_commit(git_repo, next_version, tag_format)
 
             # Increment version pointer
@@ -492,22 +722,50 @@ def build_git_flow_repo_w_3_release_channels(
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
-            # Make a 2nd release candidate (v1.1.0-rc.2)
+            # Make a 2nd release candidate (v1.1.0-alpha.2)
             create_release_tagged_commit(git_repo, next_version, tag_format)
 
             # Increment version pointer
             next_version = next(versions)
             next_version_def = repo_def[next_version]
 
-            # Change to a feature branch
-            git_repo.create_head("feature")
-            git_repo.heads.feature.checkout()
+            # checkout dev branch (in prep for merge)
+            dev_branch_head.checkout()
 
-            # Make a feature commit
-            next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo,
-                next_version_def["commits"],
+            # Merge feature branch into dev branch
+            git_repo.git.merge(
+                feat_branch_head.name,
+                no_ff=True,
+                m=next_version_def["commits"][0]["msg"],
             )
+            next_version_def["commits"][0]["sha"] = git_repo.head.commit.hexsha
+
+            # Switch to a feature branch
+            fix_branch_head = git_repo.create_head(
+                "fix/patch-1", commit=dev_branch_head.commit
+            )
+            fix_branch_head.checkout()
+
+            # Make a patch commit
+            next_version_def["commits"] = [
+                next_version_def["commits"][0],
+                *simulate_change_commits_n_rtn_changelog_entry(
+                    git_repo,
+                    next_version_def["commits"][1:-1],
+                ),
+                next_version_def["commits"][-1],
+            ]
+
+            # checkout dev branch (in prep for merge)
+            dev_branch_head.checkout()
+
+            # Merge feature branch into dev branch
+            git_repo.git.merge(
+                fix_branch_head.name,
+                no_ff=True,
+                m=next_version_def["commits"][-1]["msg"],
+            )
+            next_version_def["commits"][-1]["sha"] = git_repo.head.commit.hexsha
 
             # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
@@ -527,18 +785,38 @@ def build_git_flow_repo_w_3_release_channels(
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
-            # Make an alpha prerelease (v1.1.0-alpha.1)
+            # Make an alpha prerelease (v1.1.0-rc.1)
             create_release_tagged_commit(git_repo, next_version, tag_format)
 
             # Increment version pointer
             next_version = next(versions)
             next_version_def = repo_def[next_version]
 
+            # Switch to a feature branch
+            feat_branch_head = git_repo.create_head(
+                "feat/feature-4", commit=dev_branch_head.commit
+            )
+            feat_branch_head.checkout()
+
             # Make a another feature commit
-            next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo,
-                next_version_def["commits"],
+            next_version_def["commits"] = [
+                *simulate_change_commits_n_rtn_changelog_entry(
+                    git_repo,
+                    next_version_def["commits"][:-1],
+                ),
+                next_version_def["commits"][-1],
+            ]
+
+            # checkout dev branch (in prep for merge)
+            dev_branch_head.checkout()
+
+            # Merge feature branch into dev branch
+            git_repo.git.merge(
+                feat_branch_head.name,
+                no_ff=True,
+                m=next_version_def["commits"][-1]["msg"],
             )
+            next_version_def["commits"][-1]["sha"] = git_repo.head.commit.hexsha
 
             # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
@@ -558,18 +836,49 @@ def build_git_flow_repo_w_3_release_channels(
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
-            # Make a 2nd alpha prerelease (v1.1.0-alpha.2)
+            # Make a 2nd alpha prerelease (v1.1.0-rc.2)
             create_release_tagged_commit(git_repo, next_version, tag_format)
 
             # Increment version pointer
             next_version = next(versions)
             next_version_def = repo_def[next_version]
 
-            # Make a patch level commit
-            next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo,
-                next_version_def["commits"],
+            # Switch to a fix branch
+            fix_branch_head = git_repo.create_head(
+                "fix/patch-2", commit=dev_branch_head.commit
             )
+            fix_branch_head.checkout()
+
+            # Make a patch level commit
+            next_version_def["commits"] = [
+                *simulate_change_commits_n_rtn_changelog_entry(
+                    git_repo,
+                    next_version_def["commits"][:-2],
+                ),
+                *next_version_def["commits"][-2:],
+            ]
+
+            # checkout dev branch (in prep for merge)
+            dev_branch_head.checkout()
+
+            # Merge feature branch into dev branch
+            git_repo.git.merge(
+                fix_branch_head.name,
+                no_ff=True,
+                m=next_version_def["commits"][-2]["msg"],
+            )
+            next_version_def["commits"][-2]["sha"] = git_repo.head.commit.hexsha
+
+            # checkout main branch (in prep for merge & release)
+            main_branch_head.checkout()
+
+            # Merge dev branch into main branch
+            git_repo.git.merge(
+                dev_branch_head.name,
+                no_ff=True,
+                m=next_version_def["commits"][-1]["msg"],
+            )
+            next_version_def["commits"][-1]["sha"] = git_repo.head.commit.hexsha
 
             # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
@@ -589,7 +898,7 @@ def build_git_flow_repo_w_3_release_channels(
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
-            # Make a 3rd alpha prerelease (v1.1.0-alpha.3)
+            # Make a 3rd alpha prerelease (v1.1.0)
             create_release_tagged_commit(git_repo, next_version, tag_format)
 
         return repo_dir, hvcs
